==> translate-toolkit-3.3.6-1-any.pkg.tar.xz: usr/lib/python3.9/site-packages/translate/lang/wo.py <==
#
# Copyright 2009 Zuza Software Foundation
#
# This file is part of the Translate Toolkit.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, see <http://www.gnu.org/licenses/>.

"""This module represents the Wolof language.
"""


from translate.lang import common


class wo(common.Common):
    """This class represents Wolof."""

    validdoublewords = [
        "am",
        "baana",
        "bëgg",
        "bën",
        "dagg",
        "damm",
        "dégg",
        "fas ",
        "feeñ",
        "fël",
        "gaañ",
        "gàkk",
        "jaar",
        "jafe",
        "jam",
        "jékki",
        "koom",
        "léeg",
        "matt",
        "mën",
        "mutt",
        "ndank",
        "ŋun",
        "pas",
        "pël",
        "raŋ",
        "ray",
        "rëq",
        "saay",
        "sañ",
        "soor",
        "soox",
        "sum",
        "tàkk",
        "tàng",
        "téq",
        "tipp",
        "tolof",
        "tóor",
        "waalo",
        "waaŋ",
        "xam",
        "xar",
        "xew",
        "yëg",
        "yopp",
    ]

==> translate-toolkit-3.11.1-1-any.pkg.tar.xz: usr/lib/python3.11/site-packages/translate/lang/wo.py <==
#
# Copyright 2009 Zuza Software Foundation
#
# This file is part of the Translate Toolkit.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, see <http://www.gnu.org/licenses/>.

"""This module represents the Wolof language."""


from translate.lang import common


class wo(common.Common):
    """This class represents Wolof."""

    validdoublewords = [
        "am",
        "baana",
        "bëgg",
        "bën",
        "dagg",
        "damm",
        "dégg",
        "fas ",
        "feeñ",
        "fël",
        "gaañ",
        "gàkk",
        "jaar",
        "jafe",
        "jam",
        "jékki",
        "koom",
        "léeg",
        "matt",
        "mën",
        "mutt",
        "ndank",
        "ŋun",
        "pas",
        "pël",
        "raŋ",
        "ray",
        "rëq",
        "saay",
        "sañ",
        "soor",
        "soox",
        "sum",
        "tàkk",
        "tàng",
        "téq",
        "tipp",
        "tolof",
        "tóor",
        "waalo",
        "waaŋ",
        "xam",
        "xar",
        "xew",
        "yëg",
        "yopp",
    ]
